@@ -93,8 +93,9 @@
   :group 'hypermedia)
 
 (defcustom shimbun-x-face
-  "X-Face: Ygq$6P.,%Xt$U)DS)cRY@k$VkW!7(X'X'?U{{osjjFG\"E]hND;SPJ-J?O?R\
-|a?Lg2$0rVng\n =O3Lt}?~IId8Jj&vP^3*o=LKUyk(`t%0c!;t6REk=JbpsEn9MrN7gZ%"
+  "X-Face: @Q+y!*#)K`rvKfSQnCK.Q\\{T0qs@?plqxVu<=@H-y\
+22NlKSprlFiND7{\"{]&Ddg1=P6{Ze|\n xbW2L1p5ofS\\&u~28A\
+dJrT4Cd<Ls?U!G4}0S%FA~KegR;YZWieoc%`|$4M\\\"i*2avWm?"
   "*Default X-Face field for shimbun."
   :group 'shimbun
   :type 'string)
@@ -125,9 +126,8 @@ Return content-type of URL as string when retrieval succeeded."
   (let (type)
     (when (and url (setq type (w3m-retrieve url nil no-cache)))
       (unless no-decode
-	(let (w3m-use-refresh)
-	  (w3m-decode-buffer url)
-	  (goto-char (point-min))))
+	(w3m-decode-buffer url)
+	(goto-char (point-min)))
       type)))
 
 (defun shimbun-fetch-url (shimbun url &optional no-cache no-decode)
@@ -599,11 +599,12 @@ return the contents of this buffer as an encoded string."
 
 (defun shimbun-mime-encode-string (string)
   (condition-case nil
-      (mapconcat
-       #'identity
-       (split-string (or (eword-encode-string
-			  (shimbun-decode-entities-string string)) ""))
-       " ")
+      (save-match-data
+	(mapconcat
+	 #'identity
+	 (split-string (or (eword-encode-string
+			    (shimbun-decode-entities-string string)) ""))
+	 " "))
     (error string)))
 
 (defun shimbun-make-date-string (year month day &optional time timezone)
