@@ -1,6 +1,6 @@
 ;;; w3m-xmas.el --- The stuffs to use emacs-w3m on XEmacs
 
-;; Copyright (C) 2001, 2002 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
+;; Copyright (C) 2001, 2002, 2003 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Authors: Yuuichi Teranishi  <teranisi@gohome.org>,
 ;;          TSUCHIYA Masatoshi <tsuchiya@namazu.org>,
@@ -330,42 +330,43 @@ Third optional argument SIZE is currently ignored."
 	  (type (condition-case err
 		    (w3m-retrieve url 'raw no-cache nil referer handler)
 		  (error (message "While retrieving %s: %s" url err) nil)))
-	(let ((data (buffer-string))
-	      glyph)
-	  (setq glyph
-		(when (w3m-image-type-available-p (setq type
-							(w3m-image-type type)))
-		  (or (and (eq type 'gif)
-			   (or w3m-should-unoptimize-animated-gifs
-			       w3m-should-convert-interlaced-gifs)
-			   w3m-gifsicle-program
-			   (w3m-fix-gif url data no-cache))
-		      (w3m-make-glyph data type))))
-	  (if (and w3m-resize-images set-size)
-	      (progn
-		(setq size (cons (glyph-width glyph)
-				 (glyph-height glyph)))
-		(if (and (null (car set-size)) (cdr set-size))
-		    (setcar set-size
-			    (/ (* (car size) (cdr set-size))
-			       (cdr size))))
-		(if (and (null (cdr set-size)) (car set-size))
-		    (setcdr set-size
-			    (/ (* (cdr size) (car set-size))
-			       (car size))))
-		(if (or (not (eq (car size)
-				 (car set-size)))  ; width is different
-			(not (eq (cdr size)
-				 (cdr set-size)))) ; height is different
-		    (lexical-let ((type type))
-		      (w3m-process-do
-			  (resized (w3m-resize-image
-				    data
-				    (car set-size)(cdr set-size)
-				    handler))
-			(w3m-make-glyph resized type)))
-		  glyph))
-	    glyph))))))
+	(when type
+	  (let ((data (buffer-string))
+		glyph)
+	    (setq glyph
+		  (when (w3m-image-type-available-p
+			 (setq type (w3m-image-type type)))
+		    (or (and (eq type 'gif)
+			     (or w3m-should-unoptimize-animated-gifs
+				 w3m-should-convert-interlaced-gifs)
+			     w3m-gifsicle-program
+			     (w3m-fix-gif url data no-cache))
+			(w3m-make-glyph data type))))
+	    (if (and w3m-resize-images set-size)
+		(progn
+		  (setq size (cons (glyph-width glyph)
+				   (glyph-height glyph)))
+		  (if (and (null (car set-size)) (cdr set-size))
+		      (setcar set-size
+			      (/ (* (car size) (cdr set-size))
+				 (cdr size))))
+		  (if (and (null (cdr set-size)) (car set-size))
+		      (setcdr set-size
+			      (/ (* (cdr size) (car set-size))
+				 (car size))))
+		  (if (or (not (eq (car size)
+				   (car set-size))) ;; width is different
+			  (not (eq (cdr size)
+				   (cdr set-size)))) ;; height is different
+		      (lexical-let ((type type))
+			(w3m-process-do
+			    (resized (w3m-resize-image
+				      data
+				      (car set-size)(cdr set-size)
+				      handler))
+			  (w3m-make-glyph resized type)))
+		    glyph))
+	      glyph)))))))
 
 (defun w3m-create-resized-image (url rate &optional referer size handler)
   "Resize an cached image object.
@@ -397,19 +398,25 @@ and its cdr element is used as height."
 		  (w3m-make-glyph resized fmt)))))))))
 
 (defun w3m-insert-image (beg end image &rest args)
-  "Display image on the current buffer.
-Buffer string between BEG and END are replaced with IMAGE."
-  (let (extent glyphs)
-    (while (setq extent (extent-at beg nil 'w3m-xmas-icon extent 'at))
-      (push (extent-end-glyph extent) glyphs)
-      (set-extent-end-glyph extent nil))
+  "Display IMAGE in the current buffer.
+A buffer string between BEG and END are replaced with IMAGE."
+  (let (glyphs)
+    (map-extents
+     (lambda (extent maparg)
+       (push (extent-end-glyph extent) glyphs)
+       (set-extent-end-glyph extent nil)
+       nil)
+     nil beg beg nil nil 'w3m-xmas-icon)
+    ;; Display an image on the right hand.
     (push image glyphs)
-    ;; Image on the right is displayed.
     (when (extent-at end nil 'invisible nil 'at)
       (setq end (next-single-property-change end 'invisible))
-      (while (setq extent (extent-at end nil 'w3m-xmas-icon extent 'at))
-	(push (extent-end-glyph extent) glyphs)
-	(set-extent-end-glyph extent nil)))
+      (map-extents
+       (lambda (extent maparg)
+	 (push (extent-end-glyph extent) glyphs)
+	 (set-extent-end-glyph extent nil)
+	 nil)
+       nil end end nil nil 'w3m-xmas-icon))
     (set-extent-properties (make-extent beg end) (list 'w3m-xmas-icon t
 						       'invisible t))
     (while glyphs
@@ -418,14 +425,11 @@ Buffer string between BEG and END are replaced with IMAGE."
 				   'end-glyph (pop glyphs))))))
 
 (defun w3m-remove-image (beg end)
-  "Remove an image which is inserted between BEG and END."
-  (let (extent extents)
-    (while (setq extent (extent-at beg nil 'w3m-xmas-icon extent 'at))
-      (setq extents (push extent extents)))
-    (while (setq extent (extent-at end nil 'w3m-xmas-icon extent 'at))
-      (setq extents (push extent extents)))
-    (dolist (extent extents)
-      (delete-extent extent))))
+  "Remove images between BEG and END."
+  (map-extents (lambda (extent maparg)
+		 (delete-extent extent)
+		 nil)
+	       nil beg end nil 'end-closed 'w3m-xmas-icon))
 
 (defun w3m-image-type-available-p (image-type)
   "Return non-nil if an image with IMAGE-TYPE can be displayed inline."
